Extra — IoC 0.0.15 documentation

### Navigation

- index
- next |
- previous |
- IoC 0.0.15 documentation »

# Extra

The ioc package include some integration with some python libs, just edit the `config.yml` file and add the different following `yaml` sections.

- Event Dispatcher
  - Configuration
- Flask
  - Configuration
  - Services available
- Mailer
  - Configuration
- Redis-Py
  - Configuration
  - Services available
- redis_wrap
  - Configuration
- Twisted
  - Configuration
  - Services available

### Navigation

- index
- next |
- previous |
- IoC 0.0.15 documentation »